## Attributions - thank you!

- [Development co-author: ChatGPT (GPT4), Github copilot](https://www.openai.com)
- [Development co-author: Cursor](https://www.cursor.com)
- [Send icons created by Freepik - Flaticon](https://www.flaticon.com/free-icons/send)
- [Split Views by Nguyen Huu Phuoc](https://htmldom.dev/create-resizable-split-views/)
- [Vueform - frontend for form_yaml and form_json markdown extensions](https://vueform.com)
- [Mermaid - markdown for diagrams](https://mermaid.js.org)
- [MathJax - markdown for math](https://www.mathjax.org)
